============================
So You Want to Contribute...
============================
For general information on contributing to OpenStack, please check out the
`contributor guide <https://docs.openstack.org/contributors/>`_ to get started.
It covers all the basics that are common to all OpenStack projects: the accounts
you need, the basics of interacting with our Gerrit review system, how we
communicate as a community, etc.
Below will cover the more project specific information you need to get started
with masakari.

Communication
~~~~~~~~~~~~~
* IRC channel #openstack-masakari at OFTC
* Mailing list (prefix subjects with ``[masakari]`` for faster responses)
  http://lists.openstack.org/cgi-bin/mailman/listinfo/openstack-discuss

Contacting the Core Team
~~~~~~~~~~~~~~~~~~~~~~~~
Please refer the `masakari Core Team
<https://review.opendev.org/admin/groups/23a3cb66b177425112e8d24b8f8b5a1c662cc9e5,members>`_ contacts.

New Feature Planning
~~~~~~~~~~~~~~~~~~~~
masakari features are tracked on `Launchpad <https://bugs.launchpad.net/masakari>`_.

Task Tracking
~~~~~~~~~~~~~
We track our tasks in `Launchpad <https://bugs.launchpad.net/masakari>`_.
If you're looking for some smaller, easier work item to pick up and get started
on, search for the 'low-hanging-fruit' tag.

Reporting a Bug
~~~~~~~~~~~~~~~
You found an issue and want to make sure we are aware of it? You can do so on
`Launchpad <https://bugs.launchpad.net/masakari>`_.

Getting Your Patch Merged
~~~~~~~~~~~~~~~~~~~~~~~~~
All changes proposed to the masakari project require one or two +2 votes
from masakari core reviewers before one of the core reviewers can approve
patch by giving ``Workflow +1`` vote.

Project Team Lead Duties
~~~~~~~~~~~~~~~~~~~~~~~~
All common PTL duties are enumerated in the `PTL guide
<https://docs.openstack.org/project-team-guide/ptl.html>`_.
